SdkError

Enum SdkError 

pub enum SdkError {
Show 13 variants Auth(String), AccessDenied { resource: String, action: String, }, NotFound { entity_type: String, entity_id: String, }, RateLimit { retry_after_ms: u64, }, Unavailable(String), Timeout { timeout_ms: u64, }, Validation { field: String, constraint: String, }, Config(String), Http { status: u16, body: String, }, Serialization(Error), InvalidUrl(ParseError), Internal(String), Reqwest(Error),
}
All errors that can be returned by the ClawDB Rust SDK.

Variants



Auth(String)



AccessDenied

Fields

resource: String
action: String


NotFound

Fields

entity_type: String
entity_id: String


RateLimit

Fields

retry_after_ms: u64


Unavailable(String)



Timeout

Fields

timeout_ms: u64


Validation

Fields

field: String
constraint: String


Config(String)



Http

Fields

status: u16
body: String


Serialization(Error)



InvalidUrl(ParseError)



Internal(String)



Reqwest(Error)

Implementations

Source

impl SdkError

pub fn is_retriable(&self) -> bool

Whether the error is retriable.

pub fn from_http(status: u16, body: &str) -> Self

Maps an HTTP status code and body text to an SdkError.